@@ -4,7 +4,7 @@
 #include "lookup.h"
 
 static struct	hashlist *hashtab[HASHMAX];
-static char *strsave(char *s);
+static char *strsave(const char *s);
 
 /*
  * from K&R "The C Programming language"
@@ -13,7 +13,7 @@ static char *strsave(char *s);
  * hash - for a hash value for string s
  *
  */
-int hash(char *s)
+static int hash(const char *s)
 {
 	int	hashval;
 
@@ -26,7 +26,7 @@ int hash(char *s)
  * lookup - lookup for a string s in the hash table
  *
  */
-struct hashlist *lookup(char *s)
+struct hashlist *lookup(const char *s)
 {
 	struct hashlist *np;
 
@@ -40,10 +40,10 @@ struct hashlist *lookup(char *s)
  * install - install a string name in hashtable and its value def
  *
  */
-struct hashlist *install(char *name, char *def)
+struct hashlist *install(const char *name, char *def)
 {
 	int hashval;
-	struct hashlist *np, *lookup();
+	struct hashlist *np;
 
 	if ((np = lookup(name)) == NULL) {	/* not found.. */
 		np = (struct hashlist *) malloc(sizeof(*np));
@@ -65,7 +65,7 @@ struct hashlist *install(char *name, char *def)
  * strsave - save string s somewhere
  *
  */
-static char *strsave(char *s)
+static char *strsave(const char *s)
 {
 	char *p;
 
