@@ -1,4 +1,7 @@
 
+#ifndef LOOKUP_H
+#define LOOKUP_H
+
 /*
  * from K&R "The C Programming language"
  * Table lookup routines
@@ -17,5 +20,7 @@ struct hashlist {
 
 					/* hash table itself */
 
-extern struct hashlist *lookup(char *s);
+struct hashlist *lookup(const char *s);
+struct hashlist *install(const char *name, char *def);
 
+#endif /* LOOKUP_H */
