@@ -627,7 +627,14 @@ int gettok(char *token, int toksiz)
 {
 	int t, i;
 	int tok;
-	char name[MAXNAME+1];
+	/* gtok (called by deftok) will write beyond the token buffer in some
+	 * cases where the size is small. This is not ordinarily a problem
+	 * because no small buffers are ever passed to gtok, except here.
+	 * Allocate extra space at the end of name to avoid potential
+	 * stack corruption. The worst offender seems to be relate(), which
+	 * will use up to 6 bytes of space for a given input character.
+	 */
+	char name[MAXNAME+8];
 
 	for ( ; level >= 0; level--) {
 		for (tok = deftok(token, toksiz, infile[level]); tok != EOF;
@@ -644,7 +651,10 @@ int gettok(char *token, int toksiz)
 			else if (equal(token, incl) == NO)
 				return(tok);
 			for (i = 0; i < MAXNAME - 1; i = strlen(name)) {
-				t = deftok(&name[i], MAXNAME, infile[level]);
+				/* Reduce the size parameter passed to deftok
+				 * as i increases, so that we don't go off the
+				 * end of name. */
+				t = deftok(&name[i], MAXNAME-i, infile[level]);
 				if (t == NEWLINE || t == SEMICOL) {
 					pbstr(&name[i]);
 					break;
