@@ -1,10 +1,10 @@
-integer x,y,qwet,fgd,djr,kfy,g,jg,gk,j,sdhf,asg,agsd,ags,h,y,tsrh,sth,ruk,il,y,jd,sht,wht,wth,the,juyk,yt,tliu,rj,htw,grs,w,th,wht,hwte,erj,kut,uky,ilt,y,er,ht,wth,eht,ey,ejy,ej,e,uke,ly,liu,oy,g,t,asg,sdf,bc,ghf,rth,sbc,sdh,sh,sbc,sdf,sfhd,wrh
+integer x,y,qwet,fgd,djr,kfy,jg,gk,j,sdhf,asg,agsd,ags,h,tsrh,sth,ruk,il,jd,sht,the,juyk,yt,tliu,rj,htw,grs,w,th,wht,hwte,erj,kut,uky,ilt,er,ht,wth,eht,ey,ejy,ej,e,uke,ly,liu,oy,g,t,bc,ghf,rth,sdh,sh,sbc,sdf,sfhd,wrh
 x=1; y=2
 # sfadjlk;lkdfasjklfsjklfsdjlkfjklfdsjkl;fdsjkljklsdfjkl;dsfdfjklsjklsdfjklfsdjl;kk;sdfjkl;fsdjkl;dfsjkldsfjkl;dfsjkl;fdsjklfdsjkl;jhdsthjk;shtmk.xbgmkbvmkld;fsdjklsgjklgjkl;gsjkl;gjl;kjkl;gjkl;fgl;jkjkl
-%#define ABC def
-if((x==y) && x >=0)print *,'it works...'
-if((x==y) && _
-x <=0) _
+%      print *,'copy works...'
+if((x!=y) && x >=0)print *,'it works...'
+if((x!=y) && _
+x >=0) _
 	print *,'it works...'
 if(x == y)
 	write(6,600)
@@ -37,3 +37,8 @@ for(x=0; x < 10; x=x+1)
 603 format('x = ',i2)
 604 format('x = ',i2)
 end
+
+subroutine abc_def(x,y)
+integer x,y
+print *,'subr works'
+end
